==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QCollatorSortKey_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcollator.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCollatorSortKey(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCollatorSortKey")
    QCollatorSortKey *_ptr = reinterpret_cast<QCollatorSortKey *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QCollatorSortKey(QCollatorSortKey)
void __qt_construct_QCollatorSortKey_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCollatorSortKey(QCollatorSortKey)")
    jobject other0 = __java_arguments[0].l;
    const QCollatorSortKey& __qt_other0 = qtjambi_cast<const QCollatorSortKey& >(__jni_env, other0);
    QCollatorSortKey *__qt_this = new(__qtjambi_ptr) QCollatorSortKey(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QCollatorSortKey
void __qt_destruct_QCollatorSortKey(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCollatorSortKey")
    reinterpret_cast<QCollatorSortKey*>(ptr)->~QCollatorSortKey();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCollatorSortKey::QCollatorSortKey(QCollatorSortKey)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCollatorSortKey_initialize_1native__Lio_qt_core_QCollatorSortKey_2Lio_qt_core_QCollatorSortKey_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCollatorSortKey::QCollatorSortKey(QCollatorSortKey)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCollatorSortKey_0, sizeof(QCollatorSortKey), typeid(QCollatorSortKey), false, &deleter_QCollatorSortKey, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCollatorSortKey::operator<(QCollatorSortKey,QCollatorSortKey)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCollatorSortKey_operator_1less_1native_1cref_1QCollatorSortKey__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCollatorSortKey *__qt_this = QtJambiAPI::objectFromNativeId<QCollatorSortKey>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCollatorSortKey::operator<(QCollatorSortKey,QCollatorSortKey)", __qt_this)
        const QCollatorSortKey& __qt_rhs1 = QtJambiAPI::objectReferenceFromNativeId<QCollatorSortKey>(__jni_env, rhs1);
        __java_return_value = (*__qt_this) < __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCollatorSortKey::operator=(QCollatorSortKey)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCollatorSortKey_assign_1native_1cref_1QCollatorSortKey__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCollatorSortKey *__qt_this = QtJambiAPI::objectFromNativeId<QCollatorSortKey>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCollatorSortKey::operator=(QCollatorSortKey)", __qt_this)
        const QCollatorSortKey& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCollatorSortKey>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCollatorSortKey::swap(QCollatorSortKey&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCollatorSortKey_swap_1native_1ref_1QCollatorSortKey__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCollatorSortKey *__qt_this = QtJambiAPI::objectFromNativeId<QCollatorSortKey>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCollatorSortKey::swap(QCollatorSortKey&)", __qt_this)
        QCollatorSortKey& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCollatorSortKey>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeCustomStructors)
void* custom_constructor_QCollatorSortKey(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QCollatorSortKey* copy = static_cast<const QCollatorSortKey*>(__in_var);
    Q_UNUSED(copy)
    if(copy){
        return new(placement) QCollatorSortKey(*copy);
    }else{
        return new(placement) QCollatorSortKey(QCollator().sortKey(""));
    }
}
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCollatorSortKey_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCollatorSortKey *__qt_this = QtJambiAPI::objectFromNativeId<QCollatorSortKey>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCollatorSortKey(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCollatorSortKey>("QCollatorSortKey", "io/qt/core/QCollatorSortKey");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCollatorSortKey, {
        ConstructorInfo(&__qt_construct_QCollatorSortKey_0, "Lio/qt/core/QCollatorSortKey;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCollatorSortKey);
    registerMetaType<QCollatorSortKey>("QCollatorSortKey", &custom_constructor_QCollatorSortKey);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QCollatorSortKey_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcollator.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCollatorSortKey(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCollatorSortKey")
    QCollatorSortKey *_ptr = reinterpret_cast<QCollatorSortKey *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QCollatorSortKey(QCollatorSortKey)
void __qt_construct_QCollatorSortKey_cref_QCollatorSortKey(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCollatorSortKey(QCollatorSortKey)")
    jobject other0 = __java_arguments[0].l;
    const QCollatorSortKey& __qt_other0 = qtjambi_cast<const QCollatorSortKey& >(__jni_env, other0);
    QCollatorSortKey *__qt_this = new(__qtjambi_ptr) QCollatorSortKey(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QCollatorSortKey::QCollatorSortKey(QCollatorSortKey)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCollatorSortKey_initialize_1native__Lio_qt_core_QCollatorSortKey_2Lio_qt_core_QCollatorSortKey_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCollatorSortKey::QCollatorSortKey(QCollatorSortKey)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCollatorSortKey_cref_QCollatorSortKey, sizeof(QCollatorSortKey), typeid(QCollatorSortKey), false, &deleter_QCollatorSortKey, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QCollatorSortKey
void __qt_destruct_QCollatorSortKey(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCollatorSortKey")
    reinterpret_cast<QCollatorSortKey*>(ptr)->~QCollatorSortKey();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCollatorSortKey::operator<(QCollatorSortKey,QCollatorSortKey)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCollatorSortKey_operator_1less_1native_1cref_1QCollatorSortKey__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCollatorSortKey *__qt_this = QtJambiAPI::objectFromNativeId<QCollatorSortKey>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCollatorSortKey::operator<(QCollatorSortKey,QCollatorSortKey)", __qt_this)
        const QCollatorSortKey& __qt_rhs1 = QtJambiAPI::objectReferenceFromNativeId<QCollatorSortKey>(__jni_env, rhs1);
        __java_return_value = (*__qt_this) < __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCollatorSortKey::operator=(QCollatorSortKey)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCollatorSortKey_assign_1native_1cref_1QCollatorSortKey__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCollatorSortKey *__qt_this = QtJambiAPI::objectFromNativeId<QCollatorSortKey>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCollatorSortKey::operator=(QCollatorSortKey)", __qt_this)
        const QCollatorSortKey& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCollatorSortKey>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCollatorSortKey::swap(QCollatorSortKey&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCollatorSortKey_swap_1native_1ref_1QCollatorSortKey__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCollatorSortKey *__qt_this = QtJambiAPI::objectFromNativeId<QCollatorSortKey>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCollatorSortKey::swap(QCollatorSortKey&)", __qt_this)
        QCollatorSortKey& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCollatorSortKey>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeCustomStructors)
void* custom_constructor_QCollatorSortKey(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QCollatorSortKey* copy = static_cast<const QCollatorSortKey*>(__in_var);
    Q_UNUSED(copy)
    if(copy){
        return new(placement) QCollatorSortKey(*copy);
    }else{
        return new(placement) QCollatorSortKey(QCollator().sortKey(""));
    }
}
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCollatorSortKey_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCollatorSortKey *__qt_this = QtJambiAPI::objectFromNativeId<QCollatorSortKey>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCollatorSortKey(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCollatorSortKey>("QCollatorSortKey", "io/qt/core/QCollatorSortKey");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCollatorSortKey, {
        ConstructorInfo(&__qt_construct_QCollatorSortKey_cref_QCollatorSortKey, "Lio/qt/core/QCollatorSortKey;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCollatorSortKey);
    registerMetaType<QCollatorSortKey>("QCollatorSortKey", &custom_constructor_QCollatorSortKey);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
